@@ -193,11 +193,11 @@ sub new
   }
 
   $self->add_to_cleanup(
-    'libtest/*.o',
-    'libtest/*.obj',
-    'libtest/*.so',
-    'libtest/*.dll',
-    'libtest/*.bundle',
+    't/ffi/*.o',
+    't/ffi/*.obj',
+    't/ffi/*.so',
+    't/ffi/*.dll',
+    't/ffi/*.bundle',
     'examples/*.o',
     'examples/*.so',
     'examples/*.dll',
@@ -213,6 +213,7 @@ sub new
     'build.bat',
     'core',
     'share/config.json',
+    'share/config.pl',
     'include/ffi_platypus_config.h',
   );
 
@@ -253,7 +254,12 @@ sub ACTION_probe
   my($self) = @_;
   $self->depends_on('ac');
   require My::Probe;
-  My::Probe->probe($self);
+  My::Probe->probe(
+    $self->cbuilder,
+    $self->extra_compiler_flags,
+    $self->extra_linker_flags,
+  );
+  $self->add_to_cleanup(My::Probe->cleanup);
 }
 
 sub ACTION_build
@@ -286,7 +292,11 @@ sub ACTION_libtest
   my($self) = @_;
   $self->depends_on('ac');
   $self->depends_on('probe');
-  My::LibTest->build($self);
+  My::LibTest->build(
+    $self->cbuilder,
+    $self->extra_compiler_flags,
+    $self->extra_linker_flags,
+  );
 }
 
 sub ACTION_test
