@@ -7,7 +7,7 @@ use base qw( Exporter );
 our @EXPORT = qw( scalar_to_buffer buffer_to_scalar );
 
 # ABSTRACT: Convert scalars to C buffers
-our $VERSION = '0.47'; # VERSION
+our $VERSION = '0.56'; # VERSION
 
 
 use constant _incantation => 
@@ -41,13 +41,13 @@ FFI::Platypus::Buffer - Convert scalars to C buffers
 
 =head1 VERSION
 
-version 0.47
+version 0.56
 
 =head1 SYNOPSIS
 
  use FFI::Platypus::Buffer;
  my($pointer, $size) = scalar_to_buffer $scalar;
- my $scalar2 = buffer_to_scallar $pointer, $size;
+ my $scalar2 = buffer_to_scalar $pointer, $size;
 
 =head1 DESCRIPTION
 
@@ -68,6 +68,11 @@ L<FFI::Platypus::API> and L<FFI::Platypus::Type>.  These functions were
 taken from the now obsolete L<FFI::Util> module, as they may be useful 
 in some cases.
 
+B<Caution>: This module provides great power in the way that you
+interact with C code, but with that power comes great responsibility.
+Since you are dealing with blocks of memory you need to take care to
+understand the underlying ownership model of these pointers.
+
 =head1 FUNCTIONS
 
 =head2 scalar_to_buffer
@@ -78,6 +83,33 @@ Convert a string scalar into a buffer.  Returned in order are a pointer
 to the start of the string scalar's memory region and the size of the 
 region.
 
+You should NEVER try to free C<$pointer>.
+
+When you pass this pointer and size into a C function, it has direct
+access to the data stored in your scalar, so it is important that you
+not resize or free the scalar while it is in use by the C code.  Typically
+if you are passing a buffer into a C function which reads or writes to
+the buffer, but does not keep the pointer for later use you are okay.
+If the buffer is in use long term by the C code, then you should consider
+copying the buffer instead.  For example:
+
+ use FFI::Platypus::Buffer qw( scalar_to_buffer );
+ use FFI::Platypus::Memory qw( malloc memcpy free )
+ 
+ my($ptr, $size) = scalar_to_buffer $string;
+ c_function_thaat_does_not_keep_ptr( $ptr, $size); # okay
+ 
+ my($ptr, $size) = scalar_to_buffer $string;
+ my $ptr_copy = malloc($size);
+ memcpy($ptr_copy, $ptr, $size);
+ c_function_that_DOES_keep_ptr( $ptr_copy, $size); # also okay
+ 
+ ...
+ 
+ # later when you know that the c code is no longer using the pointer
+ # Since you allocated the copy, you are responsible for free'ing it.
+ free($ptr_copy);
+
 =head2 buffer_to_scalar
 
  my $scalar = buffer_to_scalar $pointer, $size;
@@ -85,6 +117,10 @@ region.
 Convert the buffer region defined by the pointer and size into a string 
 scalar.
 
+Because of the way memory management works in Perl, the buffer is copied
+from the buffer into the scalar.  If this pointer was returned from C
+land, then you should only free it if you allocated it.
+
 =head1 SEE ALSO
 
 =over 4
@@ -115,9 +151,15 @@ Vickenty Fesunov (vyf)
 
 Gregor Herrmann (gregoa)
 
+Shlomi Fish (shlomif)
+
+Damyan Ivanov
+
+Ilya Pavlov (Ilya33)
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Graham Ollis.
+This software is copyright (c) 2015,2016,2017,2018 by Graham Ollis.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
